==> xiaoerke-common-1.0.34-sources.jar: com/cxqm/xiaoerke/common/web/AliyunConnectorServlet.java <==
package com.cxqm.xiaoerke.common.web;

import com.ckfinder.connector.ServletContextFactory;
import com.ckfinder.connector.configuration.Configuration;
import com.ckfinder.connector.configuration.ConfigurationFactory;
import com.ckfinder.connector.configuration.IConfiguration;
import com.ckfinder.connector.configuration.Events.EventTypes;
import com.ckfinder.connector.data.BeforeExecuteCommandEventArgs;
import com.ckfinder.connector.errors.ConnectorException;
import com.ckfinder.connector.handlers.command.Command;
import com.ckfinder.connector.handlers.command.CopyFilesCommand;
import com.ckfinder.connector.handlers.command.CreateFolderCommand;
import com.ckfinder.connector.handlers.command.DeleteFilesCommand;
import com.ckfinder.connector.handlers.command.DeleteFolderCommand;
import com.ckfinder.connector.handlers.command.DownloadFileCommand;
import com.ckfinder.connector.handlers.command.ErrorCommand;
import com.ckfinder.connector.handlers.command.FileUploadCommand;
import com.ckfinder.connector.handlers.command.GetFilesCommand;
import com.ckfinder.connector.handlers.command.GetFoldersCommand;
import com.ckfinder.connector.handlers.command.IPostCommand;
import com.ckfinder.connector.handlers.command.InitCommand;
import com.ckfinder.connector.handlers.command.LoadCookiesCommand;
import com.ckfinder.connector.handlers.command.MoveFilesCommand;
import com.ckfinder.connector.handlers.command.QuickUploadCommand;
import com.ckfinder.connector.handlers.command.RenameFileCommand;
import com.ckfinder.connector.handlers.command.RenameFolderCommand;
import com.ckfinder.connector.handlers.command.ThumbnailCommand;
import com.ckfinder.connector.handlers.command.XMLCommand;
import com.ckfinder.connector.handlers.command.XMLErrorCommand;
import com.ckfinder.connector.utils.AccessControlUtil;
import java.io.IOException;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import javax.servlet.ServletConfig;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class AliyunConnectorServlet extends HttpServlet {
	private Exception startException;
	private static final long serialVersionUID = 2960665641425154338L;

	public AliyunConnectorServlet() {
	}

	protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		request.setCharacterEncoding("UTF-8");
		response.setCharacterEncoding("UTF-8");
		this.getResponse(request, response, false);
	}

	protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		request.setCharacterEncoding("UTF-8");
		response.setCharacterEncoding("UTF-8");
		this.getResponse(request, response, true);
	}

	private void getResponse(HttpServletRequest request, HttpServletResponse response, boolean post) throws ServletException {
		if(this.startException != null && Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue()) {
			throw new ServletException(this.startException);
		} else {
			String command = request.getParameter("command");
			IConfiguration configuration = null;

			try {
				configuration = ConfigurationFactory.getInstace().getConfiguration(request);
				if(configuration == null) {
					throw new Exception("Configuration wasn\'t initialized correctly. Check server logs.");
				}
			} catch (Exception var8) {
				if(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue()) {
					var8.printStackTrace();
				}

				throw new ServletException(var8);
			}

			try {
				if(command == null || command.equals("")) {
					throw new ConnectorException(10, false);
				}

				configuration.setDebugMode(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue());
				AliyunConnectorServlet.CommandHandlerEnum e = null;

				try {
					e = AliyunConnectorServlet.CommandHandlerEnum.valueOf(command.toUpperCase());
					if((e.getCommand() instanceof IPostCommand || post) && !AliyunConnectorServlet.CommandHandlerEnum.FILEUPLOAD.equals(e) && !AliyunConnectorServlet.CommandHandlerEnum.QUICKUPLOAD.equals(e)) {
						this.checkPostRequest(request);
					}
				} catch (IllegalArgumentException var9) {
					;
				}

				BeforeExecuteCommandEventArgs args = new BeforeExecuteCommandEventArgs();
				args.setCommand(command);
				args.setRequest(request);
				args.setResponse(response);
				if(configuration.getEvents() != null) {
					if(configuration.getEvents().run(EventTypes.BeforeExecuteCommand, args, configuration)) {
						e = AliyunConnectorServlet.CommandHandlerEnum.valueOf(command.toUpperCase());
						e.execute(request, response, configuration, this.getServletContext(), new Object[0]);
					}
				} else {
					e = AliyunConnectorServlet.CommandHandlerEnum.valueOf(command.toUpperCase());
					e.execute(request, response, configuration, this.getServletContext(), new Object[0]);
				}
			} catch (IllegalArgumentException var10) {
				if(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue()) {
					var10.printStackTrace();
					response.reset();
					throw new ServletException(var10);
				}

				this.handleError(new ConnectorException(10, false), configuration, request, response, command);
			} catch (ConnectorException var11) {
				if(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue() && var11.getException() != null) {
					var11.getException().printStackTrace();
					response.reset();
					throw new ServletException(var11.getException());
				}

				this.handleError(var11, configuration, request, response, command);
			} catch (Exception var12) {
				if(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue()) {
					var12.printStackTrace();
					response.reset();
					throw new ServletException(var12);
				}

				this.handleError(new ConnectorException(var12), configuration, request, response, command);
			}

		}
	}

	private void checkPostRequest(HttpServletRequest request) throws ConnectorException {
		if(request.getParameter("CKFinderCommand") == null || !request.getParameter("CKFinderCommand").equals("true")) {
			throw new ConnectorException(109, true);
		}
	}

	private void handleError(ConnectorException e, IConfiguration configuration, HttpServletRequest request, HttpServletResponse response, String currentCommand) throws ServletException {
		try {
			if(currentCommand != null) {
				Command e1 = AliyunConnectorServlet.CommandHandlerEnum.valueOf(currentCommand.toUpperCase()).getCommand();
				if(e1 instanceof XMLCommand) {
					AliyunConnectorServlet.CommandHandlerEnum.XMLERROR.execute(request, response, configuration, this.getServletContext(), new Object[]{e});
				} else {
					AliyunConnectorServlet.CommandHandlerEnum.ERROR.execute(request, response, configuration, this.getServletContext(), new Object[]{e});
				}
			} else {
				AliyunConnectorServlet.CommandHandlerEnum.XMLERROR.execute(request, response, configuration, this.getServletContext(), new Object[]{e});
			}

		} catch (Exception var7) {
			throw new ServletException(var7);
		}
	}

	public void init() throws ServletException {
		try {
			Field servletContextField = ServletContextFactory.class.getDeclaredField("servletContext");
			if (servletContextField != null) {
				servletContextField.setAccessible(true);
				servletContextField.set(null, this.getServletContext());
			}
		} catch (IllegalAccessException e) {
			e.printStackTrace();
		} catch (NoSuchFieldException e) {
			e.printStackTrace();
		}
//		ServletContextFactory.setServletContext(this.getServletContext());
		Object configuration = null;

		try {
			String e = this.getServletConfig().getInitParameter("configuration");
			if(e != null) {
				Class clazz = Class.forName(e);
				if(clazz.getConstructor(new Class[]{ServletConfig.class}) != null) {
					configuration = (IConfiguration)clazz.getConstructor(new Class[]{ServletConfig.class}).newInstance(new Object[]{this.getServletConfig()});
				} else {
					configuration = (IConfiguration)clazz.newInstance();
				}
			} else {
				configuration = new Configuration(this.getServletConfig());
			}
		} catch (Exception var4) {
			configuration = new Configuration(this.getServletConfig());
		}

		try {
			((IConfiguration)configuration).init();
			AccessControlUtil.getInstance((IConfiguration)configuration).loadACLConfig();
		} catch (Exception var5) {
			if(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue()) {
				var5.printStackTrace();
			}

			this.startException = var5;
			configuration = null;
		}

		ConfigurationFactory.getInstace().setConfiguration((IConfiguration)configuration);
	}

	private static enum CommandHandlerEnum {
		INIT(new CKFAliyunInitCommand()),
		GETFOLDERS(new CKFAliyunGetFoldersCommand()),
		GETFILES(new CKFAliyunGetFilesCommand()),
		LOADCOOKIES(new LoadCookiesCommand()),
		THUMBNAIL(new CKFAliyunThumbnailCommand()),
		DOWNLOADFILE(new DownloadFileCommand()),
		CREATEFOLDER(new CreateFolderCommand()),
		RENAMEFILE(new CKFAliyunRenameFileCommand()),
		RENAMEFOLDER(new RenameFolderCommand()),
		DELETEFOLDER(new DeleteFolderCommand()),
		COPYFILES(new CopyFilesCommand()),
		MOVEFILES(new MoveFilesCommand()),
		DELETEFILES(new CKFAliyunDeleteFilesCommand()),
		FILEUPLOAD(new CKFAliyunFileUploadCommand()),
		QUICKUPLOAD(new CKFAliyunQuickUploadCommand()),
		XMLERROR(new XMLErrorCommand()),
		ERROR(new ErrorCommand());

		private Command command;

		private CommandHandlerEnum(Command command1) {
			this.command = command1;
		}

		private void execute(HttpServletRequest request, HttpServletResponse response, IConfiguration configuration, ServletContext sc, Object... params) throws ConnectorException {
			Command com = null;

			try {
				com = (Command)this.command.getClass().newInstance();
			} catch (IllegalAccessException var8) {
				throw new ConnectorException(10);
			} catch (InstantiationException var9) {
				throw new ConnectorException(10);
			}

			if(com == null) {
				throw new ConnectorException(10);
			} else {
				com.runCommand(request, response, configuration, params);
			}
		}

		public Command getCommand() {
			return this.command;
		}
	}
}

==> xiaoerke-common-1.0.106-sources.jar: com/cxqm/xiaoerke/common/web/AliyunConnectorServlet.java <==
package com.cxqm.xiaoerke.common.web;

import com.ckfinder.connector.ServletContextFactory;
import com.ckfinder.connector.configuration.Configuration;
import com.ckfinder.connector.configuration.ConfigurationFactory;
import com.ckfinder.connector.configuration.IConfiguration;
import com.ckfinder.connector.configuration.Events.EventTypes;
import com.ckfinder.connector.data.BeforeExecuteCommandEventArgs;
import com.ckfinder.connector.errors.ConnectorException;
import com.ckfinder.connector.handlers.command.Command;
import com.ckfinder.connector.handlers.command.CopyFilesCommand;
import com.ckfinder.connector.handlers.command.CreateFolderCommand;
import com.ckfinder.connector.handlers.command.DeleteFilesCommand;
import com.ckfinder.connector.handlers.command.DeleteFolderCommand;
import com.ckfinder.connector.handlers.command.DownloadFileCommand;
import com.ckfinder.connector.handlers.command.ErrorCommand;
import com.ckfinder.connector.handlers.command.FileUploadCommand;
import com.ckfinder.connector.handlers.command.GetFilesCommand;
import com.ckfinder.connector.handlers.command.GetFoldersCommand;
import com.ckfinder.connector.handlers.command.IPostCommand;
import com.ckfinder.connector.handlers.command.InitCommand;
import com.ckfinder.connector.handlers.command.LoadCookiesCommand;
import com.ckfinder.connector.handlers.command.MoveFilesCommand;
import com.ckfinder.connector.handlers.command.QuickUploadCommand;
import com.ckfinder.connector.handlers.command.RenameFileCommand;
import com.ckfinder.connector.handlers.command.RenameFolderCommand;
import com.ckfinder.connector.handlers.command.ThumbnailCommand;
import com.ckfinder.connector.handlers.command.XMLCommand;
import com.ckfinder.connector.handlers.command.XMLErrorCommand;
import com.ckfinder.connector.utils.AccessControlUtil;
import com.cxqm.xiaoerke.common.filter.CKFAliyunBukert;
import org.springframework.beans.factory.annotation.Autowired;

import java.io.IOException;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import javax.servlet.ServletConfig;
import javax.servlet.ServletContext;
import javax.servlet.ServletException;
import javax.servlet.http.HttpServlet;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

public class AliyunConnectorServlet extends HttpServlet {
	private Exception startException;
	private static final long serialVersionUID = 2960665641425154338L;

	public AliyunConnectorServlet() {
	}

	protected void doGet(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		request.setCharacterEncoding("UTF-8");
		response.setCharacterEncoding("UTF-8");
		this.getResponse(request, response, false);
	}

	protected void doPost(HttpServletRequest request, HttpServletResponse response) throws ServletException, IOException {
		request.setCharacterEncoding("UTF-8");
		response.setCharacterEncoding("UTF-8");
		this.getResponse(request, response, true);
	}

	private void getResponse(HttpServletRequest request, HttpServletResponse response, boolean post) throws ServletException {

		CKFAliyunBukert.clear();

		String buketKey = request.getParameter("buketKey");

		String userId = request.getParameter("userId");

		if(buketKey != null && !"".equals(buketKey == null ? "" : buketKey.trim())){

			CKFAliyunBukert.setBuketKey(buketKey);

		}

		if(userId != null && !"".equals(userId == null ? "" : userId.trim())){

			CKFAliyunBukert.setUserId(userId);

		}

		if(this.startException != null && Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue()) {
			throw new ServletException(this.startException);
		} else {
			String command = request.getParameter("command");
			IConfiguration configuration = null;

			try {
				configuration = ConfigurationFactory.getInstace().getConfiguration(request);
				if(configuration == null) {
					throw new Exception("Configuration wasn\'t initialized correctly. Check server logs.");
				}
			} catch (Exception var8) {
				if(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue()) {
					var8.printStackTrace();
				}

				throw new ServletException(var8);
			}

			try {
				if(command == null || command.equals("")) {
					throw new ConnectorException(10, false);
				}

				configuration.setDebugMode(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue());
				AliyunConnectorServlet.CommandHandlerEnum e = null;

				try {
					e = AliyunConnectorServlet.CommandHandlerEnum.valueOf(command.toUpperCase());
					if((e.getCommand() instanceof IPostCommand || post) && !AliyunConnectorServlet.CommandHandlerEnum.FILEUPLOAD.equals(e) && !AliyunConnectorServlet.CommandHandlerEnum.QUICKUPLOAD.equals(e)) {
						this.checkPostRequest(request);
					}
				} catch (IllegalArgumentException var9) {
					;
				}

				BeforeExecuteCommandEventArgs args = new BeforeExecuteCommandEventArgs();
				args.setCommand(command);
				args.setRequest(request);
				args.setResponse(response);
				if(configuration.getEvents() != null) {
					if(configuration.getEvents().run(EventTypes.BeforeExecuteCommand, args, configuration)) {
						e = AliyunConnectorServlet.CommandHandlerEnum.valueOf(command.toUpperCase());
						e.execute(request, response, configuration, this.getServletContext(), new Object[0]);
					}
				} else {
					e = AliyunConnectorServlet.CommandHandlerEnum.valueOf(command.toUpperCase());
					e.execute(request, response, configuration, this.getServletContext(), new Object[0]);
				}
			} catch (IllegalArgumentException var10) {
				if(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue()) {
					var10.printStackTrace();
					response.reset();
					throw new ServletException(var10);
				}

				this.handleError(new ConnectorException(10, false), configuration, request, response, command);
			} catch (ConnectorException var11) {
				if(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue() && var11.getException() != null) {
					var11.getException().printStackTrace();
					response.reset();
					throw new ServletException(var11.getException());
				}

				this.handleError(var11, configuration, request, response, command);
			} catch (Exception var12) {
				if(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue()) {
					var12.printStackTrace();
					response.reset();
					throw new ServletException(var12);
				}

				this.handleError(new ConnectorException(var12), configuration, request, response, command);
			}

		}
	}

	private void checkPostRequest(HttpServletRequest request) throws ConnectorException {
		if(request.getParameter("CKFinderCommand") == null || !request.getParameter("CKFinderCommand").equals("true")) {
			throw new ConnectorException(109, true);
		}
	}

	private void handleError(ConnectorException e, IConfiguration configuration, HttpServletRequest request, HttpServletResponse response, String currentCommand) throws ServletException {
		try {
			if(currentCommand != null) {
				Command e1 = AliyunConnectorServlet.CommandHandlerEnum.valueOf(currentCommand.toUpperCase()).getCommand();
				if(e1 instanceof XMLCommand) {
					AliyunConnectorServlet.CommandHandlerEnum.XMLERROR.execute(request, response, configuration, this.getServletContext(), new Object[]{e});
				} else {
					AliyunConnectorServlet.CommandHandlerEnum.ERROR.execute(request, response, configuration, this.getServletContext(), new Object[]{e});
				}
			} else {
				AliyunConnectorServlet.CommandHandlerEnum.XMLERROR.execute(request, response, configuration, this.getServletContext(), new Object[]{e});
			}

		} catch (Exception var7) {
			throw new ServletException(var7);
		}
	}

	public void init() throws ServletException {
		try {
			Field servletContextField = ServletContextFactory.class.getDeclaredField("servletContext");
			if (servletContextField != null) {
				servletContextField.setAccessible(true);
				servletContextField.set(null, this.getServletContext());
			}
		} catch (IllegalAccessException e) {
			e.printStackTrace();
		} catch (NoSuchFieldException e) {
			e.printStackTrace();
		}
//		ServletContextFactory.setServletContext(this.getServletContext());
		Object configuration = null;

		try {
			String e = this.getServletConfig().getInitParameter("configuration");
			if(e != null) {
				Class clazz = Class.forName(e);
				if(clazz.getConstructor(new Class[]{ServletConfig.class}) != null) {
					configuration = (IConfiguration)clazz.getConstructor(new Class[]{ServletConfig.class}).newInstance(new Object[]{this.getServletConfig()});
				} else {
					configuration = (IConfiguration)clazz.newInstance();
				}
			} else {
				configuration = new Configuration(this.getServletConfig());
			}
		} catch (Exception var4) {
			configuration = new Configuration(this.getServletConfig());
		}

		try {
			((IConfiguration)configuration).init();
			AccessControlUtil.getInstance((IConfiguration)configuration).loadACLConfig();
		} catch (Exception var5) {
			if(Boolean.valueOf(this.getServletConfig().getInitParameter("debug")).booleanValue()) {
				var5.printStackTrace();
			}

			this.startException = var5;
			configuration = null;
		}

		ConfigurationFactory.getInstace().setConfiguration((IConfiguration)configuration);
	}

	private static enum CommandHandlerEnum {
		INIT(new CKFAliyunInitCommand()),
		GETFOLDERS(new CKFAliyunGetFoldersCommand()),
		GETFILES(new CKFAliyunGetFilesCommand()),
		LOADCOOKIES(new LoadCookiesCommand()),
		THUMBNAIL(new CKFAliyunThumbnailCommand()),
		DOWNLOADFILE(new DownloadFileCommand()),
		CREATEFOLDER(new CreateFolderCommand()),
		RENAMEFILE(new CKFAliyunRenameFileCommand()),
		RENAMEFOLDER(new RenameFolderCommand()),
		DELETEFOLDER(new DeleteFolderCommand()),
		COPYFILES(new CopyFilesCommand()),
		MOVEFILES(new MoveFilesCommand()),
		DELETEFILES(new CKFAliyunDeleteFilesCommand()),
		FILEUPLOAD(new CKFAliyunFileUploadCommand()),
		QUICKUPLOAD(new CKFAliyunQuickUploadCommand()),
		XMLERROR(new XMLErrorCommand()),
		ERROR(new ErrorCommand());

		private Command command;

		private CommandHandlerEnum(Command command1) {
			this.command = command1;
		}

		private void execute(HttpServletRequest request, HttpServletResponse response, IConfiguration configuration, ServletContext sc, Object... params) throws ConnectorException {
			Command com = null;

			String userId = request.getParameter("userId");

			if(userId != null && !"".equals(userId == null ? "" : userId.trim())){

			}

			try {
				com = (Command)this.command.getClass().newInstance();
			} catch (IllegalAccessException var8) {
				throw new ConnectorException(10);
			} catch (InstantiationException var9) {
				throw new ConnectorException(10);
			}

			if(com == null) {
				throw new ConnectorException(10);
			} else {
				com.runCommand(request, response, configuration, params);
			}
		}

		public Command getCommand() {
			return this.command;
		}
	}
}
